==> cscec5b-wzxt-api-3.0.1-20230104.072920-220-sources.jar: com/ejianc/business/wzxt/vo/CtPlanRefVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 总控计划实体明细
 *
 * @author generator
 *
 */
public class CtPlanRefVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long controlId; // 主表主键ID
    private String materialSourceId; // 物资来源主键
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialSourceTypeId; // 物资类别来源id
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private BigDecimal num; // 计划数量
    private BigDecimal controlNum; // 总控数量
    private BigDecimal planNum;          // 累计发起计划数量
    private BigDecimal sumorderNum;     // 累计采购数量
    private BigDecimal SumInNum; // 累计进场数量
    private BigDecimal surplusPlanNum; // 剩余计划数量
    private String memo; // 备注
    private String def1; // 自定义字段
    private String def2; // 自定义字段
    private String def3; // 自定义字段
    private String def4; // 自定义字段
    private String def5; // 自定义字段
    private String sourceId; // 来源主键

    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getSumorderNum() {
        return sumorderNum;
    }

    public void setSumorderNum(BigDecimal sumorderNum) {
        this.sumorderNum = sumorderNum;
    }

    public BigDecimal getSumInNum() {
        return SumInNum;
    }

    public void setSumInNum(BigDecimal sumInNum) {
        SumInNum = sumInNum;
    }

    public BigDecimal getSurplusPlanNum() {
        return surplusPlanNum;
    }

    public void setSurplusPlanNum(BigDecimal surplusPlanNum) {
        this.surplusPlanNum = surplusPlanNum;
    }

    /**
     * 主表主键ID
     */
    public Long getControlId() {
        return controlId;
    }

    /**
     * 主表主键ID
     */
    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    /**
     * 物资来源主键
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别来源id
     */
    public String getMaterialSourceTypeId() {
        return materialSourceTypeId;
    }

    /**
     * 物资类别来源id
     */
    public void setMaterialSourceTypeId(String materialSourceTypeId) {
        this.materialSourceTypeId = materialSourceTypeId;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public BigDecimal getNum() {
        return num;
    }

    /**
     * 计划数量
     */
    public void setNum(BigDecimal num) {
        this.num = num;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

}

==> cscec5b-wzxt-api-3.0.1-20231114.075446-349-sources.jar: com/ejianc/business/wzxt/vo/CtPlanRefVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 总控计划实体明细
 *
 * @author generator
 *
 */
public class CtPlanRefVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long controlId; // 主表主键ID
    private String materialSourceId; // 物资来源主键
    private Long materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialSourceTypeId; // 物资类别来源id
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private BigDecimal num; // 计划数量
    private BigDecimal controlNum; // 总控数量
    private BigDecimal planNum;          // 累计发起计划数量
    private BigDecimal sumorderNum;     // 累计采购数量
    private BigDecimal SumInNum; // 累计进场数量
    private BigDecimal surplusPlanNum; // 剩余计划数量
    private String memo; // 备注
    private String def1; // 自定义字段
    private String def2; // 自定义字段
    private String def3; // 自定义字段
    private String def4; // 自定义字段
    private String def5; // 自定义字段
    private String sourceId; // 来源主键
    private BigDecimal scale; //控制比例

    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getSumorderNum() {
        return sumorderNum;
    }

    public void setSumorderNum(BigDecimal sumorderNum) {
        this.sumorderNum = sumorderNum;
    }

    public BigDecimal getSumInNum() {
        return SumInNum;
    }

    public void setSumInNum(BigDecimal sumInNum) {
        SumInNum = sumInNum;
    }

    public BigDecimal getSurplusPlanNum() {
        return surplusPlanNum;
    }

    public void setSurplusPlanNum(BigDecimal surplusPlanNum) {
        this.surplusPlanNum = surplusPlanNum;
    }

    /**
     * 主表主键ID
     */
    public Long getControlId() {
        return controlId;
    }

    /**
     * 主表主键ID
     */
    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    /**
     * 物资来源主键
     */
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    /**
     * 物资来源主键
     */
    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    /**
     * 物资主键
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别来源id
     */
    public String getMaterialSourceTypeId() {
        return materialSourceTypeId;
    }

    /**
     * 物资类别来源id
     */
    public void setMaterialSourceTypeId(String materialSourceTypeId) {
        this.materialSourceTypeId = materialSourceTypeId;
    }
    /**
     * 物资类别
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计划数量
     */
    public BigDecimal getNum() {
        return num;
    }

    /**
     * 计划数量
     */
    public void setNum(BigDecimal num) {
        this.num = num;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    /**
     * 自定义字段
     */
    public String getDef1() {
        return def1;
    }

    /**
     * 自定义字段
     */
    public void setDef1(String def1) {
        this.def1 = def1;
    }
    /**
     * 自定义字段
     */
    public String getDef2() {
        return def2;
    }

    /**
     * 自定义字段
     */
    public void setDef2(String def2) {
        this.def2 = def2;
    }
    /**
     * 自定义字段
     */
    public String getDef3() {
        return def3;
    }

    /**
     * 自定义字段
     */
    public void setDef3(String def3) {
        this.def3 = def3;
    }
    /**
     * 自定义字段
     */
    public String getDef4() {
        return def4;
    }

    /**
     * 自定义字段
     */
    public void setDef4(String def4) {
        this.def4 = def4;
    }
    /**
     * 自定义字段
     */
    public String getDef5() {
        return def5;
    }

    /**
     * 自定义字段
     */
    public void setDef5(String def5) {
        this.def5 = def5;
    }
    /**
     * 来源主键
     */
    public String getSourceId() {
        return sourceId;
    }

    /**
     * 来源主键
     */
    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public BigDecimal getScale() {
        return scale;
    }

    public void setScale(BigDecimal scale) {
        this.scale = scale;
    }
}
